#include <avr/io.h>
#include <stdlib.h>
#include "spi.h"
#include "lis.h"

void lis_init()
{
	LIS_SPI_Init();
	//TODO: bit defines in lis.h
	unsigned char byte = 0b01000010; //set 3 wire spi mode, block update on
	byte |= FULL_SCALE<<7; //set full scale mode
	lis_write_register( CTRL_REG2, byte ); //set 3 wire spi mode, block update on
	lis_write_register( CTRL_REG1, 0b11110111 ); //power on, samplerate to 2.56kHz, all axes enabled
	lis_write_register( CTRL_REG3, 0b00010000 ); //Hp Filter on

}


void lis_write_register( unsigned char adress, unsigned char data )
{
	LIS_SPI_Enable();

	adress &= ~(1<<7);	//set direction bit to write
	adress &= ~(1<<6);	//set m/s bit to single

	LIS_SPI_PutChar( adress );
	LIS_SPI_PutChar( data );

	LIS_SPI_Disable();
}

unsigned char lis_read_register( unsigned char adress )
{
	LIS_SPI_Enable();

	adress |=  (1<<7);	//set direction bit to read
	adress &= ~(1<<6);	//set m/s bit to single

	LIS_SPI_PutChar( adress );

	unsigned char data;
	data = LIS_SPI_GetChar();

	LIS_SPI_Disable();

	return data;
}

void lis_write_multiple_registers( unsigned char adress, unsigned char size, unsigned char* data )
{
	LIS_SPI_Enable();

	adress &= ~(1<<7);	//set direction bit to write
	adress |=  (1<<6);	//set m/s bit to multi

	LIS_SPI_PutChar( adress );
	for ( unsigned char i  = 0; i < size; i++ )
	{
		LIS_SPI_PutChar( data[i] );
	}

	LIS_SPI_Disable();
}

void lis_read_multiple_registers( unsigned char adress, unsigned char size, unsigned char* data )
{
	LIS_SPI_Enable();

	adress |=  (1<<7);	//set direction bit to read
	adress |=  (1<<6);	//set m/s bit to multi

	LIS_SPI_PutChar( adress );
	
	for ( unsigned char i = 0; i < size; i++ )
	{
		data[i] = LIS_SPI_GetChar();
	}

	LIS_SPI_Disable();
}
